==> request-tracker4_4.4.4%2Bdfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/it.js <==
﻿/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'it', {
	euro: 'Simbolo Euro',
	lsquo: 'Virgoletta singola sinistra',
	rsquo: 'Virgoletta singola destra',
	ldquo: 'Virgolette aperte',
	rdquo: 'Virgolette chiuse',
	ndash: 'Trattino',
	mdash: 'Trattino lungo',
	iexcl: 'Punto esclavamativo invertito',
	cent: 'Simbolo Cent',
	pound: 'Simbolo Sterlina',
	curren: 'Simbolo Moneta',
	yen: 'Simbolo Yen',
	brvbar: 'Barra interrotta',
	sect: 'Simbolo di sezione',
	uml: 'Dieresi',
	copy: 'Simbolo Copyright',
	ordf: 'Indicatore ordinale femminile',
	laquo: 'Virgolette basse aperte',
	not: 'Nessun segno',
	reg: 'Simbolo Registrato',
	macr: 'Macron',
	deg: 'Simbolo Grado',
	sup2: 'Apice Due',
	sup3: 'Apice Tre',
	acute: 'Accento acuto',
	micro: 'Simbolo Micro',
	para: 'Simbolo Paragrafo',
	middot: 'Punto centrale',
	cedil: 'Cediglia',
	sup1: 'Apice Uno',
	ordm: 'Indicatore ordinale maschile',
	raquo: 'Virgolette basse chiuse',
	frac14: 'Frazione volgare un quarto',
	frac12: 'Frazione volgare un mezzo',
	frac34: 'Frazione volgare tre quarti',
	iquest: 'Punto interrogativo invertito',
	Agrave: 'Lettera maiuscola latina A con accento grave',
	Aacute: 'Lettera maiuscola latina A con accento acuto',
	Acirc: 'Lettera maiuscola latina A con accento circonflesso',
	Atilde: 'Lettera maiuscola latina A con tilde',
	Auml: 'Lettera maiuscola latina A con dieresi',
	Aring: 'Lettera maiuscola latina A con anello sopra',
	AElig: 'Lettera maiuscola latina AE',
	Ccedil: 'Lettera maiuscola latina C con cediglia',
	Egrave: 'Lettera maiuscola latina E con accento grave',
	Eacute: 'Lettera maiuscola latina E con accento acuto',
	Ecirc: 'Lettera maiuscola latina E con accento circonflesso',
	Euml: 'Lettera maiuscola latina E con dieresi',
	Igrave: 'Lettera maiuscola latina I con accento grave',
	Iacute: 'Lettera maiuscola latina I con accento acuto',
	Icirc: 'Lettera maiuscola latina I con accento circonflesso',
	Iuml: 'Lettera maiuscola latina I con dieresi',
	ETH: 'Lettera maiuscola latina Eth',
	Ntilde: 'Lettera maiuscola latina N con tilde',
	Ograve: 'Lettera maiuscola latina O con accento grave',
	Oacute: 'Lettera maiuscola latina O con accento acuto',
	Ocirc: 'Lettera maiuscola latina O con accento circonflesso',
	Otilde: 'Lettera maiuscola latina O con tilde',
	Ouml: 'Lettera maiuscola latina O con dieresi',
	times: 'Simbolo di moltiplicazione',
	Oslash: 'Lettera maiuscola latina O barrata',
	Ugrave: 'Lettera maiuscola latina U con accento grave',
	Uacute: 'Lettera maiuscola latina U con accento acuto',
	Ucirc: 'Lettera maiuscola latina U con accento circonflesso',
	Uuml: 'Lettera maiuscola latina U con accento circonflesso',
	Yacute: 'Lettera maiuscola latina Y con accento acuto',
	THORN: 'Lettera maiuscola latina Thorn',
	szlig: 'Lettera latina minuscola doppia S',
	agrave: 'Lettera minuscola latina a con accento grave',
	aacute: 'Lettera minuscola latina a con accento acuto',
	acirc: 'Lettera minuscola latina a con accento circonflesso',
	atilde: 'Lettera minuscola latina a con tilde',
	auml: 'Lettera minuscola latina a con dieresi',
	aring: 'Lettera minuscola latina a con anello superiore',
	aelig: 'Lettera minuscola latina ae',
	ccedil: 'Lettera minuscola latina c con cediglia',
	egrave: 'Lettera minuscola latina e con accento grave',
	eacute: 'Lettera minuscola latina e con accento acuto',
	ecirc: 'Lettera minuscola latina e con accento circonflesso',
	euml: 'Lettera minuscola latina e con dieresi',
	igrave: 'Lettera minuscola latina i con accento grave',
	iacute: 'Lettera minuscola latina i con accento acuto',
	icirc: 'Lettera minuscola latina i con accento circonflesso',
	iuml: 'Lettera minuscola latina i con dieresi',
	eth: 'Lettera minuscola latina eth',
	ntilde: 'Lettera minuscola latina n con tilde',
	ograve: 'Lettera minuscola latina o con accento grave',
	oacute: 'Lettera minuscola latina o con accento acuto',
	ocirc: 'Lettera minuscola latina o con accento circonflesso',
	otilde: 'Lettera minuscola latina o con tilde',
	ouml: 'Lettera minuscola latina o con dieresi',
	divide: 'Simbolo di divisione',
	oslash: 'Lettera minuscola latina o barrata',
	ugrave: 'Lettera minuscola latina u con accento grave',
	uacute: 'Lettera minuscola latina u con accento acuto',
	ucirc: 'Lettera minuscola latina u con accento circonflesso',
	uuml: 'Lettera minuscola latina u con dieresi',
	yacute: 'Lettera minuscola latina y con accento acuto',
	thorn: 'Lettera minuscola latina thorn',
	yuml: 'Lettera minuscola latina y con dieresi',
	OElig: 'Legatura maiuscola latina OE',
	oelig: 'Legatura minuscola latina oe',
	'372': 'Lettera maiuscola latina W con accento circonflesso',
	'374': 'Lettera maiuscola latina Y con accento circonflesso',
	'373': 'Lettera minuscola latina w con accento circonflesso',
	'375': 'Lettera minuscola latina y con accento circonflesso',
	sbquo: 'Singola virgoletta bassa low-9',
	'8219': 'Singola virgoletta bassa low-9 inversa',
	bdquo: 'Doppia virgoletta bassa low-9',
	hellip: 'Ellissi orizzontale',
	trade: 'Simbolo TM',
	'9658': 'Puntatore nero rivolto verso destra',
	bull: 'Punto',
	rarr: 'Freccia verso destra',
	rArr: 'Doppia freccia verso destra',
	hArr: 'Doppia freccia sinistra destra',
	diams: 'Simbolo nero diamante',
	asymp: 'Quasi uguale a'
} );

==> request-tracker5_5.0.3%2Bdfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/it.js <==
/**
 * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'it', {
	euro: 'Simbolo Euro',
	lsquo: 'Virgoletta singola sinistra',
	rsquo: 'Virgoletta singola destra',
	ldquo: 'Virgolette aperte',
	rdquo: 'Virgolette chiuse',
	ndash: 'Trattino',
	mdash: 'Trattino lungo',
	iexcl: 'Punto esclavamativo invertito',
	cent: 'Simbolo Cent',
	pound: 'Simbolo Sterlina',
	curren: 'Simbolo Moneta',
	yen: 'Simbolo Yen',
	brvbar: 'Barra interrotta',
	sect: 'Simbolo di sezione',
	uml: 'Dieresi',
	copy: 'Simbolo Copyright',
	ordf: 'Indicatore ordinale femminile',
	laquo: 'Virgolette basse aperte',
	not: 'Nessun segno',
	reg: 'Simbolo Registrato',
	macr: 'Macron',
	deg: 'Simbolo Grado',
	sup2: 'Apice Due',
	sup3: 'Apice Tre',
	acute: 'Accento acuto',
	micro: 'Simbolo Micro',
	para: 'Simbolo Paragrafo',
	middot: 'Punto centrale',
	cedil: 'Cediglia',
	sup1: 'Apice Uno',
	ordm: 'Indicatore ordinale maschile',
	raquo: 'Virgolette basse chiuse',
	frac14: 'Frazione volgare un quarto',
	frac12: 'Frazione volgare un mezzo',
	frac34: 'Frazione volgare tre quarti',
	iquest: 'Punto interrogativo invertito',
	Agrave: 'Lettera maiuscola latina A con accento grave',
	Aacute: 'Lettera maiuscola latina A con accento acuto',
	Acirc: 'Lettera maiuscola latina A con accento circonflesso',
	Atilde: 'Lettera maiuscola latina A con tilde',
	Auml: 'Lettera maiuscola latina A con dieresi',
	Aring: 'Lettera maiuscola latina A con anello sopra',
	AElig: 'Lettera maiuscola latina Æ',
	Ccedil: 'Lettera maiuscola latina C con cediglia',
	Egrave: 'Lettera maiuscola latina E con accento grave',
	Eacute: 'Lettera maiuscola latina E con accento acuto',
	Ecirc: 'Lettera maiuscola latina E con accento circonflesso',
	Euml: 'Lettera maiuscola latina E con dieresi',
	Igrave: 'Lettera maiuscola latina I con accento grave',
	Iacute: 'Lettera maiuscola latina I con accento acuto',
	Icirc: 'Lettera maiuscola latina I con accento circonflesso',
	Iuml: 'Lettera maiuscola latina I con dieresi',
	ETH: 'Lettera maiuscola latina Eth',
	Ntilde: 'Lettera maiuscola latina N con tilde',
	Ograve: 'Lettera maiuscola latina O con accento grave',
	Oacute: 'Lettera maiuscola latina O con accento acuto',
	Ocirc: 'Lettera maiuscola latina O con accento circonflesso',
	Otilde: 'Lettera maiuscola latina O con tilde',
	Ouml: 'Lettera maiuscola latina O con dieresi',
	times: 'Simbolo di moltiplicazione',
	Oslash: 'Lettera maiuscola latina O barrata',
	Ugrave: 'Lettera maiuscola latina U con accento grave',
	Uacute: 'Lettera maiuscola latina U con accento acuto',
	Ucirc: 'Lettera maiuscola latina U con accento circonflesso',
	Uuml: 'Lettera maiuscola latina U con accento circonflesso',
	Yacute: 'Lettera maiuscola latina Y con accento acuto',
	THORN: 'Lettera maiuscola latina Thorn',
	szlig: 'Lettera latina minuscola doppia S',
	agrave: 'Lettera minuscola latina a con accento grave',
	aacute: 'Lettera minuscola latina a con accento acuto',
	acirc: 'Lettera minuscola latina a con accento circonflesso',
	atilde: 'Lettera minuscola latina a con tilde',
	auml: 'Lettera minuscola latina a con dieresi',
	aring: 'Lettera minuscola latina a con anello superiore',
	aelig: 'Lettera minuscola latina ae',
	ccedil: 'Lettera minuscola latina c con cediglia',
	egrave: 'Lettera minuscola latina e con accento grave',
	eacute: 'Lettera minuscola latina e con accento acuto',
	ecirc: 'Lettera minuscola latina e con accento circonflesso',
	euml: 'Lettera minuscola latina e con dieresi',
	igrave: 'Lettera minuscola latina i con accento grave',
	iacute: 'Lettera minuscola latina i con accento acuto',
	icirc: 'Lettera minuscola latina i con accento circonflesso',
	iuml: 'Lettera minuscola latina i con dieresi',
	eth: 'Lettera minuscola latina eth',
	ntilde: 'Lettera minuscola latina n con tilde',
	ograve: 'Lettera minuscola latina o con accento grave',
	oacute: 'Lettera minuscola latina o con accento acuto',
	ocirc: 'Lettera minuscola latina o con accento circonflesso',
	otilde: 'Lettera minuscola latina o con tilde',
	ouml: 'Lettera minuscola latina o con dieresi',
	divide: 'Simbolo di divisione',
	oslash: 'Lettera minuscola latina o barrata',
	ugrave: 'Lettera minuscola latina u con accento grave',
	uacute: 'Lettera minuscola latina u con accento acuto',
	ucirc: 'Lettera minuscola latina u con accento circonflesso',
	uuml: 'Lettera minuscola latina u con dieresi',
	yacute: 'Lettera minuscola latina y con accento acuto',
	thorn: 'Lettera minuscola latina thorn',
	yuml: 'Lettera minuscola latina y con dieresi',
	OElig: 'Legatura maiuscola latina OE',
	oelig: 'Legatura minuscola latina oe',
	'372': 'Lettera maiuscola latina W con accento circonflesso',
	'374': 'Lettera maiuscola latina Y con accento circonflesso',
	'373': 'Lettera minuscola latina w con accento circonflesso',
	'375': 'Lettera minuscola latina y con accento circonflesso',
	sbquo: 'Singola virgoletta bassa low-9',
	'8219': 'Singola virgoletta bassa low-9 inversa',
	bdquo: 'Doppia virgoletta bassa low-9',
	hellip: 'Ellissi orizzontale',
	trade: 'Simbolo TM',
	'9658': 'Puntatore nero rivolto verso destra',
	bull: 'Punto',
	rarr: 'Freccia verso destra',
	rArr: 'Doppia freccia verso destra',
	hArr: 'Doppia freccia sinistra destra',
	diams: 'Simbolo nero diamante',
	asymp: 'Quasi uguale a'
} );
